@@ -16,10 +16,10 @@ from oslo_utils import timeutils
 
 from keystoneclient import utils
 
-__all__ = ['DiscoveryList',
+__all__ = ('DiscoveryList',
            'V2Discovery',
            'V3Discovery',
-           ]
+           )
 
 _DEFAULT_DAYS_AGO = 30
 
@@ -77,7 +77,7 @@ class DiscoveryBase(dict):
 
     @updated.setter
     def updated(self, value):
-        self.updated_str = timeutils.isotime(value)
+        self.updated_str = utils.isotime(value)
 
     @utils.positional()
     def add_link(self, href, rel='self', type=None):
